import { Center, HStack, Image, Pressable, ScrollView, Text, VStack } from "native-base"
import { useEffect } from "react"
import { DrawerScreenProps } from "@react-navigation/drawer"
import { RootDrawerParamList } from "../Navigation"

interface ItemPreviewProps {
    caption: string
    title: string
    name?: string
    image?: string
    itemId: string
    navigation: any
}

const ItemPreview = (props: ItemPreviewProps) => {

    useEffect(() => {
        console.log("ItemPreview", "Props:", props)
    }, [props])

    return (
        <>
            <Pressable
                onPress={() => props.navigation.navigate("Item", {itemId: props.itemId})}
                key={props.itemId}
            >
                <HStack
                    space={ 2 }
                    flex={ 1 }
                    alignItems={ "start" }
                >
                    <Image
                        source={ {uri: `http:/147.228.173.159/static/images/${ props.image ? "thumb-" + props.image : "thumb-Rel-78.png" }`} }
                        size={ "sm" }
                        alt={ props.image ? props.image : "thumb-Rel-78.png" }
                    />
                    <VStack h={70}>
                        <Text fontSize={"sm"} italic>{ props.name }</Text>
                        <Text fontSize={"sm"} bold noOfLines={1}>{ props.caption }</Text>
                        <Text fontSize={"xs"}>{ props.title }</Text>
                    </VStack>
                </HStack>
            </Pressable>
        </>
    )
}

export default ItemPreview